# Directord

A deployment framework built to manage the data center life cycle.

> Task driven deployment, simplified, directed by you.

Directord is an asynchronous deployment and operations platform with the aim to
better enable simplicity, faster time to delivery, and consistency.

## Design Principles

The Directord design principles can be
[found here](https://cloudnull.github.io/directord#first-principles).

## Documentation

Additional documentation covering everything from application design, wire
diagrams, installation, usage, and more can all be
[found here](https://cloudnull.github.io/directord).

## Welcome Contributors

* Read documentation on how best to deploy and leverage directord.

* When ready, if you'd like to contribute to Directord pull-requests are very
  welcomed. Directord is an open platform built for operators. If you see
  something broken, please feel free to raise a but and/or fix it.

* Information on running tests can be [found here](https://cloudnull.github.io/directord/testing).

## License

Apache License Version 2.0
[COPY](LICENSE)
